#!/bin/sh

GNOME_BROWSER=`gconftool-2 --get /desktop/gnome/url-handlers/http/command | sed s/%s//`
which konqueror &> /dev/null
[ $? = 0 ] && KONQUEROR=konqueror
which mozilla &> /dev/null
[ $? = 0 ] && MOZILLA=mozilla
which netscape &> /dev/null
[ $? = 0 ] && NETSCAPE=netscape

( [ "$GNOME_BROWSER" != '' ] && $GNOME_BROWSER "$1" ) ||
( [ "$HELP_BROWSER" != '' ] && $HELP_BROWSER "$1" ) ||
( [ "$BROWSER" != '' ] && $BROWSER "$1" ) ||
( [ "$KONQUEROR" != '' ] && $KONQUEROR "$1" ) ||
( [ "$MOZILLA" != '' ] && $MOZILLA "$1" ) ||
( [ "$NETSCAPE" != '' ] && $NETSCAPE "$1" )
